summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/boot.c4
-rw-r--r--src/check.c2
-rw-r--r--src/fat.c2
-rw-r--r--src/fatlabel.c (renamed from src/dosfslabel.c)14
-rw-r--r--src/fsck.fat.c (renamed from src/dosfsck.c)8
-rw-r--r--src/fsck.fat.h (renamed from src/dosfsck.h)2
-rw-r--r--src/io.c2
-rw-r--r--src/lfn.c2
-rw-r--r--src/mkfs.fat.c (renamed from src/mkdosfs.c)10
-rw-r--r--src/version.h4
10 files changed, 25 insertions, 25 deletions
diff --git a/src/boot.c b/src/boot.c
index a8dcad5..03b5375 100644
--- a/src/boot.c
+++ b/src/boot.c
@@ -31,7 +31,7 @@
#include <time.h>
#include "common.h"
-#include "dosfsck.h"
+#include "fsck.fat.h"
#include "fat.h"
#include "io.h"
#include "boot.h"
@@ -293,7 +293,7 @@ static char print_fat_dirty_state(void)
"2) No action\n");
return get_key("12", "?");
} else
- printf(" Automaticaly removing dirty bit.\n");
+ printf(" Automatically removing dirty bit.\n");
return '1';
}
diff --git a/src/check.c b/src/check.c
index a3fcc93..40ef533 100644
--- a/src/check.c
+++ b/src/check.c
@@ -31,7 +31,7 @@
#include <time.h>
#include "common.h"
-#include "dosfsck.h"
+#include "fsck.fat.h"
#include "io.h"
#include "fat.h"
#include "file.h"
diff --git a/src/fat.c b/src/fat.c
index 27fe9af..1ac3b99 100644
--- a/src/fat.c
+++ b/src/fat.c
@@ -30,7 +30,7 @@
#include <unistd.h>
#include "common.h"
-#include "dosfsck.h"
+#include "fsck.fat.h"
#include "io.h"
#include "check.h"
#include "fat.h"
diff --git a/src/dosfsck.h b/src/fsck.fat.h
index e53bf31..9646762 100644
--- a/src/dosfsck.h
+++ b/src/fsck.fat.h
@@ -1,4 +1,4 @@
-/* dosfsck.h - Common data structures and global variables
+/* fsck.fat.h - Common data structures and global variables
Copyright (C) 1993 Werner Almesberger <werner.almesberger@lrc.di.epfl.ch>
Copyright (C) 1998 Roman Hodek <Roman.Hodek@informatik.uni-erlangen.de>
diff --git a/src/io.c b/src/io.c
index d862fcf..e8c3591 100644
--- a/src/io.c
+++ b/src/io.c
@@ -42,7 +42,7 @@
#include <fcntl.h>
#include <linux/fd.h>
-#include "dosfsck.h"
+#include "fsck.fat.h"
#include "common.h"
#include "io.h"
diff --git a/src/lfn.c b/src/lfn.c
index bacf873..cf7abd9 100644
--- a/src/lfn.c
+++ b/src/lfn.c
@@ -28,7 +28,7 @@
#include "common.h"
#include "io.h"
-#include "dosfsck.h"
+#include "fsck.fat.h"
#include "lfn.h"
#include "file.h"
diff --git a/src/version.h b/src/version.h
index 6c5ab91..0c17248 100644
--- a/src/version.h
+++ b/src/version.h
@@ -23,7 +23,7 @@
#ifndef _version_h
#define _version_h
-#define VERSION "3.0.17"
-#define VERSION_DATE "29 May 2013"
+#define VERSION "3.0.18"
+#define VERSION_DATE "06 Jun 2013"
#endif
diff --git a/src/dosfslabel.c b/src/fatlabel.c
index edfb60c..56502e2 100644
--- a/src/dosfslabel.c
+++ b/src/fatlabel.c
@@ -1,4 +1,4 @@
/* dosfslabel.c - User interface
Copyright (C) 1993 Werner Almesberger <werner.almesberger@lrc.di.epfl.ch>
Copyright (C) 1998 Roman Hodek <Roman.Hodek@informatik.uni-erlangen.de>
@@ -33,7 +33,7 @@
#include <ctype.h>
#include "common.h"
-#include "dosfsck.h"
+#include "fsck.fat.h"
#include "io.h"
#include "boot.h"
#include "fat.h"
@@ -50,7 +50,7 @@ static void usage(int error)
FILE *f = error ? stderr : stdout;
int status = error ? 1 : 0;
- fprintf(f, "usage: dosfslabel device [label]\n");
+ fprintf(f, "usage: fatlabel device [label]\n");
exit(status);
}
@@ -103,7 +103,7 @@ int main(int argc, char *argv[])
if (!strcmp(argv[1], "-h") || !strcmp(argv[1], "--help"))
usage(0);
else if (!strcmp(argv[1], "-V") || !strcmp(argv[1], "--version")) {
- printf("dosfslabel " VERSION ", " VERSION_DATE ", FAT32, LFN\n");
+ printf("fatlabel " VERSION ", " VERSION_DATE ", FAT32, LFN\n");
exit(0);
}
@@ -112,14 +112,14 @@ int main(int argc, char *argv[])
strncpy(label, argv[2], 11);
if (strlen(argv[2]) > 11) {
fprintf(stderr,
- "dosfslabel: labels can be no longer than 11 characters\n");
+ "fatlabel: labels can be no longer than 11 characters\n");
exit(1);
}
- for (i = 0; i < 11; i++)
+ for (i = 0; label[i] && i < 11; i++)
/* don't know if here should be more strict !uppercase(label[i])*/
if (islower(label[i])) {
fprintf(stderr,
- "dosfslabel: labels cannot contain lower case characters\n");
+ "fatlabel: labels cannot contain lower case characters\n");
exit(1);
}
rw = 1;
@@ -1,4 +1,4 @@
-/* dosfslabel.c - User interface
+/* fatlabel.c - User interface
Copyright (C) 1993 Werner Almesberger <werner.almesberger@lrc.di.epfl.ch>
Copyright (C) 1998 Roman Hodek <Roman.Hodek@informatik.uni-erlangen.de>
diff --git a/src/dosfsck.c b/src/fsck.fat.c
index f7c1f4f..92761aa 100644
--- a/src/dosfsck.c
+++ b/src/fsck.fat.c
@@ -1,4 +1,4 @@
/* dosfsck.c - User interface
Copyright (C) 1993 Werner Almesberger <werner.almesberger@lrc.di.epfl.ch>
Copyright (C) 1998 Roman Hodek <Roman.Hodek@informatik.uni-erlangen.de>
@@ -34,7 +34,7 @@
#include <getopt.h>
#include "common.h"
-#include "dosfsck.h"
+#include "fsck.fat.h"
#include "io.h"
#include "boot.h"
#include "fat.h"
@@ -156,7 +156,7 @@ int main(int argc, char **argv)
break;
case 'v':
verbose = 1;
- printf("dosfsck " VERSION " (" VERSION_DATE ")\n");
+ printf("mkfs.fat " VERSION " (" VERSION_DATE ")\n");
break;
case 'V':
verify = 1;
@@ -175,7 +175,7 @@ int main(int argc, char **argv)
if (optind != argc - 1)
usage(argv[0]);
- printf("dosfsck " VERSION ", " VERSION_DATE ", FAT32, LFN\n");
+ printf("mkfs.fat " VERSION ", " VERSION_DATE ", FAT32, LFN\n");
fs_open(argv[optind], rw);
read_boot(&fs);
@@ -1,4 +1,4 @@
-/* dosfsck.c - User interface
+/* mkfs.fat.c - User interface
Copyright (C) 1993 Werner Almesberger <werner.almesberger@lrc.di.epfl.ch>
Copyright (C) 1998 Roman Hodek <Roman.Hodek@informatik.uni-erlangen.de>
diff --git a/src/mkdosfs.c b/src/mkfs.fat.c
index 4142052..6f2503a 100644
--- a/src/mkdosfs.c
+++ b/src/mkfs.fat.c
@@ -1,4 +1,4 @@
/* mkdosfs.c - utility to create FAT/MS-DOS filesystems
Copyright (C) 1991 Linus Torvalds <torvalds@klaava.helsinki.fi>
Copyright (C) 1992-1993 Remy Card <card@masi.ibp.fr>
@@ -28,7 +28,7 @@
under Linux. A lot of the basic structure of this program has been
borrowed from Remy Card's "mke2fs" code.
- As far as possible the aim here is to make the "mkdosfs" command
+ As far as possible the aim here is to make the "mkfs.fat" command
look almost identical to the other Linux filesystem make utilties,
eg bad blocks are still specified as blocks, not sectors, but when
it comes down to it, DOS is tied to the idea of a sector (512 bytes
@@ -249,7 +249,7 @@ char dummy_boot_code[BOOTCODE_SIZE] = "\x0e" /* push cs */
/* Global variables - the root of all evil :-) - see these and weep! */
-static char *program_name = "mkdosfs"; /* Name of the program */
+static char *program_name = "mkfs.fat"; /* Name of the program */
static char *device_name = NULL; /* Name of the device on which to create the filesystem */
static int atari_format = 0; /* Use Atari variation of MS-DOS FS format */
static int check = FALSE; /* Default to no readablity checking */
@@ -746,7 +746,7 @@ static void setup_tables(void)
strcpy((char *)bs.system_id, "kdosf");
}
else
- strcpy((char *)bs.system_id, "mkdosfs");
+ strcpy((char *)bs.system_id, "mkfs.fat");
if (sectors_per_cluster)
bs.cluster_size = (char)sectors_per_cluster;
if (size_fat == 32) {
@@ -1348,7 +1348,7 @@ static void write_tables(void)
static void usage(void)
{
fatal_error("\
-Usage: mkdosfs [-a][-A][-c][-C][-v][-I][-l bad-block-file][-b backup-boot-sector]\n\
+Usage: mkfs.fat [-a][-A][-c][-C][-v][-I][-l bad-block-file][-b backup-boot-sector]\n\
[-m boot-msg-file][-n volume-name][-i volume-id]\n\
[-s sectors-per-cluster][-S logical-sector-size][-f number-of-FATs]\n\
[-h hidden-sectors][-F fat-size][-r root-dir-entries][-R reserved-sectors]\n\
@@ -1,4 +1,4 @@
-/* mkdosfs.c - utility to create FAT/MS-DOS filesystems
+/* mkfs.fat.c - utility to create FAT/MS-DOS filesystems
Copyright (C) 1991 Linus Torvalds <torvalds@klaava.helsinki.fi>
Copyright (C) 1992-1993 Remy Card <card@masi.ibp.fr>